@@ -1,5 +1,6 @@
-/*  This file is part of the KDE project
+/*
     Copyright (C) 2008 Matthias Kretz <kretz@kde.org>
+    Copyright (C) 2013 Harald Sitter <sitter@kde.org>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -15,7 +16,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
     02110-1301, USA.
-
 */
 
 #include "phononserver.h"
@@ -40,6 +40,7 @@
 #include <QtDBus/QDBusMessage>
 #include <QtDBus/QDBusMetaType>
 #include <QtCore/QVariant>
+#include <phonon/pulsesupport.h>
 #include <Solid/AudioInterface>
 #include <Solid/GenericInterface>
 #include <Solid/Device>
@@ -381,9 +382,17 @@ static void removeOssOnlyDevices(QList<PS::DeviceInfo> *list)
 
 void PhononServer::findDevices()
 {
-    KConfigGroup globalConfigGroup(m_config, "Globals");
-    //const int cacheVersion = globalConfigGroup.readEntry("CacheVersion", 0);
-    // cacheVersion 1 is KDE 4.1, 0 is KDE 4.0
+    if (Phonon::PulseSupport *pulse = Phonon::PulseSupport::getInstance()) {
+        // NOTE: This is relying on internal behavior....
+        //       enable internally simply sets a bool that is later && with the
+        //       actually PA activity.
+        //       Should this function ever start doing more, this will break horribly.
+        pulse->enable();
+        if (pulse->isActive()) {
+            kDebug(601) << "Not looking for devices as Phonon::PulseSupport is active.";
+            return;
+        }
+    }
 
     // Fetch the full list of audio and video devices from Solid
     const QList<Solid::Device> &solidAudioDevices =
@@ -423,6 +432,8 @@ void PhononServer::findDevices()
         int cardNum = -1;
         int deviceNum = -1;
 
+        kDebug(601) << "looking at device:" << audioIface->name() << audioIface->driverHandle();
+
         bool capture = audioIface->deviceType() & Solid::AudioInterface::AudioInput;
         bool playback = audioIface->deviceType() & Solid::AudioInterface::AudioOutput;
 
@@ -692,11 +703,16 @@ void PhononServer::findDevices()
     QList<int> askToRemoveAudioIndexes;
     QList<int> askToRemoveVideoIndexes;
 
+    kDebug(601) << "groups:" << groupList;
+    kDebug(601) << "already found devices:" << alreadyFoundCards;
+
     foreach (const QString &groupName, groupList) {
         if (alreadyFoundCards.contains(groupName)) {
             continue;
         }
 
+        kDebug(601) << "group not found:" << groupName;
+
         const bool isAudio = groupName.startsWith(QLatin1String("AudioDevice_"));
         const bool isVideo = groupName.startsWith(QLatin1String("VideoDevice_"));
         const bool isPlayback = isAudio && groupName.endsWith(QLatin1String("playback"));
@@ -1081,11 +1097,15 @@ void PhononServer::askToRemoveDevices(const QStringList &devList, int type, cons
     if (!areAudio && !areVideo)
         return;
 
+    const QString &dontEverAsk = QLatin1String("phonon_always_forget_devices");
     const QString &dontAskAgainName = QLatin1String("phonon_forget_devices_") +
         devList.join(QLatin1String("_"));
 
+    // Please note that dontEverAsk overrides the device specific lists
+    // i.e. if it is set we always return
     KMessageBox::ButtonCode result;
-    if (!KMessageBox::shouldBeShownYesNo(dontAskAgainName, result)) {
+    if (!KMessageBox::shouldBeShownYesNo(dontEverAsk, result) ||
+            !KMessageBox::shouldBeShownYesNo(dontAskAgainName, result)) {
         if (result == KMessageBox::Yes) {
             if (areAudio) {
                 kDebug(601) << "removeAudioDevices" << indexes;
